@@ -4,9 +4,15 @@
 #'   700 nm) and the corresponding x, y, and z chromaticity coordinates.
 #'   Original data from A chroma_spct object with variables as follows:
 #'
-#' @details \itemize{ \item w.length (nm) \item x \item y \item z }
+#' @details
+#' \itemize{
+#' \item w.length (nm)
+#' \item x
+#' \item y
+#' \item z }
 #'
 #' @docType data
 #' @keywords datasets
 #' @format A data frame with 81 rows and 4 variables
-"beesxyzCMF.spct"
+#' @name beesxyzCMF.spct
+NULL
