@@ -41,7 +41,7 @@ oper.e.generic_spct <- function(e1, e2, oper) {
                         e1$counts, e2$counts,
                         bin.oper=oper, trim="intersection")
       names(z)[2] <- "counts"
-      setRawSpct(z, strict.range = FALSE)
+      setRawSpct(z, strict.range = getOption("photobiology.strict.range", default = FALSE))
       return(z)
     } else {
       warning("operation between 'raw_spct' and ", class(e2)[1],
@@ -57,7 +57,7 @@ oper.e.generic_spct <- function(e1, e2, oper) {
                         e1$cps, e2$cps,
                         bin.oper=oper, trim="intersection")
     names(z)[2] <- "cps"
-    setCpsSpct(z, strict.range = FALSE)
+    setCpsSpct(z, strict.range = getOption("photobiology.strict.range", default = FALSE))
     return(z)
     } else {
       warning("operation between 'cps_spct' and ", class(e2)[1],
@@ -94,7 +94,7 @@ oper.e.generic_spct <- function(e1, e2, oper) {
                          s.e.irrad = e1$s.e.irrad * mult,
                           time.unit=getTimeUnit(e1),
                          bswf.used=bswf.used,
-                         strict.range = FALSE))
+                         strict.range = getOption("photobiology.strict.range", default = FALSE)))
     }
     if (is.numeric(e2)) {
       z <- e1
@@ -121,7 +121,7 @@ oper.e.generic_spct <- function(e1, e2, oper) {
                         bin.oper=oper, trim="intersection")
       names(z)[2] <- "s.e.irrad"
       setSourceSpct(z, time.unit=getTimeUnit(e1), bswf.used = bswf.used,
-                    strict.range = FALSE)
+                    strict.range = getOption("photobiology.strict.range", default = FALSE))
       return(z)
     } else if (class2 == "filter_spct") {
       filter.quantity <- getOption("photobiology.filter.qty", default="transmittance")
@@ -136,7 +136,7 @@ oper.e.generic_spct <- function(e1, e2, oper) {
                           bin.oper=oper, trim="intersection")
         names(z)[2] <- "s.e.irrad"
         setSourceSpct(z, time.unit=getTimeUnit(e1), bswf.used = getBSWFUsed(e1),
-                      strict.range = FALSE)
+                      strict.range = getOption("photobiology.strict.range", default = FALSE))
       } else if (filter.quantity=="absorbance") {
         if (!identical(oper, `*`) && !identical(oper, `/`)) {
           warning("Only '*' and '/' are allowed between source_spct and filter_spct objects")
@@ -160,7 +160,7 @@ oper.e.generic_spct <- function(e1, e2, oper) {
                         bin.oper=oper, trim="intersection")
       names(z)[2] <- "s.e.irrad"
       setSourceSpct(z, time.unit=getTimeUnit(e1), bswf.used = getBSWFUsed(e1),
-                    strict.range = FALSE)
+                    strict.range = getOption("photobiology.strict.range", default = FALSE))
       return(z)
     } else if (class2 == "response_spct") {
       q2e(e2, action = "replace", byref = TRUE)
@@ -221,7 +221,7 @@ oper.e.generic_spct <- function(e1, e2, oper) {
                           bin.oper=oper, trim="intersection")
         names(z)[2] <- "s.e.irrad"
         setSourceSpct(z, time.unit=getTimeUnit(e2), bswf.used = getBSWFUsed(e2),
-                      strict.range = FALSE)
+                      strict.range = getOption("photobiology.strict.range", default = FALSE))
       } else if (class2 == "filter_spct") {
         e2 <- A2T(e2)
         if (!identical(oper, `*`) && !identical(oper, `/`)) {
@@ -232,7 +232,7 @@ oper.e.generic_spct <- function(e1, e2, oper) {
                           e1$Tfr, e2$Tfr,
                           bin.oper=oper, trim="intersection")
         names(z)[2] <- "Tfr"
-        setFilterSpct(z, strict.range = FALSE)
+        setFilterSpct(z, strict.range = getOption("photobiology.strict.range", default = FALSE))
         return(z)
       } else { # this traps optically illegal operations
         warning("The operation attempted in undefined according to Optics laws or the input is malformed")
@@ -269,7 +269,7 @@ oper.e.generic_spct <- function(e1, e2, oper) {
                           e1$A, e2$A,
                           bin.oper=oper, trim="intersection")
         names(z)[2] <- "A"
-        setFilterSpct(z, strict.range = FALSE)
+        setFilterSpct(z, strict.range = getOption("photobiology.strict.range", default = FALSE))
         return(z)
       } else { # this traps optically illegal operations
         warning("The operation attempted in undefined according to Optics laws or the input is malformed")
@@ -287,7 +287,7 @@ oper.e.generic_spct <- function(e1, e2, oper) {
                         e1$Rfr, e2$Rfr,
                         bin.oper=oper, trim="intersection")
       names(z)[2] <- "Rfr"
-      setReflectorSpct(z, strict.range = FALSE)
+      setReflectorSpct(z, strict.range = getOption("photobiology.strict.range", default = FALSE))
       return(z)
     } else if (class2 == "source_spct") {
       if (!identical(oper, `*`) && !identical(oper, `/`)) {
@@ -299,7 +299,7 @@ oper.e.generic_spct <- function(e1, e2, oper) {
                         bin.oper=oper, trim="intersection")
       names(z)[2] <- "s.e.irrad"
       setSourceSpct(z, time.unit=getTimeUnit(e2), bswf.used = getBSWFUsed(e2),
-                    strict.range = FALSE)
+                    strict.range = getOption("photobiology.strict.range", default = FALSE))
       return(z)
     } else { # this traps optically illegal operations
       warning("The operation attempted in undefined according to Optics laws or the input is malformed")
@@ -395,17 +395,17 @@ oper.e.generic_spct <- function(e1, e2, oper) {
       if (filter.quantity=="transmittance") {
         A2T(e2, action = "add", byref = TRUE)
         return(filter_spct(w.length=e2$w.length, Tfr=oper(e1, e2$Tfr),
-                           strict.range = FALSE))
+                           strict.range = getOption("photobiology.strict.range", default = FALSE)))
       } else if (filter.quantity=="absorbance") {
         T2A(e2, action = "add", byref = TRUE)
         return(filter_spct(w.length=e2$w.length, A=oper(e1, e2$A),
-                           strict.range = FALSE))
+                           strict.range = getOption("photobiology.strict.range", default = FALSE)))
       } else {
         stop("Assertion failed: bug in code!")
       }
     } else if (class2 == "reflector_spct") {
       return(reflector_spct(w.length=e2$w.length, Rfr=oper(e1, e2$Rfr),
-                            strict.range = FALSE))
+                            strict.range = getOption("photobiology.strict.range", default = FALSE)))
     } else if (class2 == "response_spct") {
       q2e(e2, action = "replace", byref = TRUE)
       return(response_spct(w.length=e2$w.length,
@@ -472,7 +472,7 @@ oper.q.generic_spct <- function(e1, e2, oper) {
                         e1$counts, e2$counts,
                         bin.oper=oper, trim="intersection")
       names(z)[2] <- "counts"
-      setRawSpct(z, strict.range = FALSE)
+      setRawSpct(z, strict.range = getOption("photobiology.strict.range", default = FALSE))
       return(z)
     } else {
       warning("operation between 'raw_spct' and ", class(e2)[1],
@@ -488,7 +488,7 @@ oper.q.generic_spct <- function(e1, e2, oper) {
                         e1$cps, e2$cps,
                         bin.oper=oper, trim="intersection")
       names(z)[2] <- "cps"
-      setCpsSpct(z, strict.range = FALSE)
+      setCpsSpct(z, strict.range = getOption("photobiology.strict.range", default = FALSE))
       return(z)
     } else {
       warning("operation between 'cps_spct' and ", class(e2)[1],
@@ -526,7 +526,7 @@ oper.q.generic_spct <- function(e1, e2, oper) {
                                                            default = FALSE))
       return(source_spct(w.length=e1$w.length, s.q.irrad = e1$s.q.irrad * mult,
                          bswf.used = bswf.used, time.unit=getTimeUnit(e1),
-                         strict.range = FALSE))
+                         strict.range = getOption("photobiology.strict.range", default = FALSE)))
      }
     if (is.numeric(e2)) {
       z <- e1
@@ -553,7 +553,7 @@ oper.q.generic_spct <- function(e1, e2, oper) {
                         bin.oper=oper, trim="intersection")
       names(z)[2] <- "s.q.irrad"
       setSourceSpct(z, time.unit = getTimeUnit(e1), bswf.used = bswf.used,
-                    strict.range = FALSE)
+                    strict.range = getOption("photobiology.strict.range", default = FALSE))
       return(z)
     } else if (class2 == "filter_spct") {
       filter.quantity <- getOption("photobiology.filter.qty", default="transmittance")
@@ -568,7 +568,7 @@ oper.q.generic_spct <- function(e1, e2, oper) {
                           bin.oper=oper, trim="intersection")
         names(z)[2] <- "s.q.irrad"
         setSourceSpct(z, time.unit = getTimeUnit(e1), bswf.used = getBSWFUsed(e1),
-                      strict.range = FALSE)
+                      strict.range = getOption("photobiology.strict.range", default = FALSE))
       } else if (filter.quantity=="absorbance") {
         if (!identical(oper, `*`)) return(NA)
         T2A(e2, action = "add", byref = TRUE)
@@ -586,7 +586,7 @@ oper.q.generic_spct <- function(e1, e2, oper) {
                         bin.oper=oper, trim="intersection")
       names(z)[2] <- "s.q.irrad"
       setSourceSpct(z, time.unit = getTimeUnit(e1), bswf.used = getBSWFUsed(e1),
-                    strict.range = FALSE)
+                    strict.range = getOption("photobiology.strict.range", default = FALSE))
       return(z)
     } else if (class2 == "response_spct") {
       if (!identical(oper, `*`)) return(NA)
@@ -634,7 +634,7 @@ oper.q.generic_spct <- function(e1, e2, oper) {
                           bin.oper=oper, trim="intersection")
         names(z)[2] <- "s.q.irrad"
         setSourceSpct(z, time.unit = getTimeUnit(e2), bswf.used = getBSWFUsed(e2),
-                      strict.range = FALSE)
+                      strict.range = getOption("photobiology.strict.range", default = FALSE))
       } else if (class2 == "filter_spct") {
         e2 <- A2T(e2)
         if (!identical(oper, `*`)) return(NA)
@@ -642,7 +642,7 @@ oper.q.generic_spct <- function(e1, e2, oper) {
                           e1$Tfr, e2$Tfr,
                           bin.oper=oper, trim="intersection")
         names(z)[2] <- "Tfr"
-        setFilterSpct(z, strict.range = FALSE)
+        setFilterSpct(z, strict.range = getOption("photobiology.strict.range", default = FALSE))
         return(z)
       } else { # this traps optically illegal operations
         warning("The operation attempted in undefined according to Optics laws or the input is malformed")
@@ -672,7 +672,7 @@ oper.q.generic_spct <- function(e1, e2, oper) {
                           e1$A, e2$A,
                           bin.oper=oper, trim="intersection")
         names(z)[2] <- "A"
-        setFilterSpct(z, strict.range = FALSE)
+        setFilterSpct(z, strict.range = getOption("photobiology.strict.range", default = FALSE))
         return(z)
       } else { # this traps optically illegal operations
         warning("The operation attempted in undefined according to Optics laws or the input is malformed")
@@ -689,7 +689,7 @@ oper.q.generic_spct <- function(e1, e2, oper) {
                         e1$Rfr, e2$Rfr,
                         bin.oper=oper, trim="intersection")
       names(z)[2] <- "Rfr"
-      setReflectorSpct(z, strict.range = FALSE)
+      setReflectorSpct(z, strict.range = getOption("photobiology.strict.range", default = FALSE))
       return(z)
     } else if (class2 == "source_spct") {
       if (!identical(oper, `*`)) return(NA)
@@ -699,7 +699,7 @@ oper.q.generic_spct <- function(e1, e2, oper) {
                         bin.oper=oper, trim="intersection")
       names(z)[2] <- "s.q.irrad"
       setSourceSpct(z, time.unit = getTimeUnit(e2), bswf.used = getBSWFUsed(e2),
-                    strict.range = FALSE)
+                    strict.range = getOption("photobiology.strict.range", default = FALSE))
       return(z)
     } else { # this traps optically illegal operations
       warning("The operation attempted is undefined according to Optics laws or the input is malformed")
@@ -774,15 +774,15 @@ oper.q.generic_spct <- function(e1, e2, oper) {
       filter.quantity <- getOption("photobiology.filter.qty", default="transmittance")
       if (filter.quantity=="transmittance") {
         A2T(e2, action = "add", byref = TRUE)
-        return(filter_spct(w.length=e2$w.length, Tfr=oper(e1, e2$Tfr), strict.range = FALSE))
+        return(filter_spct(w.length=e2$w.length, Tfr=oper(e1, e2$Tfr), strict.range = getOption("photobiology.strict.range", default = FALSE)))
       } else if (filter.quantity=="absorbance") {
         T2A(e2, action = "add", byref = TRUE)
-        return(filter_spct(w.length=e2$w.length, A=oper(e1, e2$A), strict.range = FALSE))
+        return(filter_spct(w.length=e2$w.length, A=oper(e1, e2$A), strict.range = getOption("photobiology.strict.range", default = FALSE)))
       } else {
         stop("Assertion failed: bug in code!")
       }
     } else if (class2 == "reflector_spct") {
-      return(reflector_spct(w.length=e2$w.length, Rfr=oper(e1, e2$Rfr), strict.range = FALSE))
+      return(reflector_spct(w.length=e2$w.length, Rfr=oper(e1, e2$Rfr), strict.range = getOption("photobiology.strict.range", default = FALSE)))
     } else if (class2 == "response_spct") {
       e2q(e2, action = "replace", byref = TRUE)
       return(response_spct(w.length=e2$w.length, s.q.response=oper(e1, e2$s.q.response)))
@@ -1310,7 +1310,7 @@ A2T <- function(x, action, byref, ...) UseMethod("A2T")
 #'
 #' @export
 #'
-A2T.default <- function(x, action=NULL, byref=FALSE, ...) {
+A2T.default <- function(x, action=NULL, byref = FALSE, ...) {
   return(10^-x)
 }
 
@@ -1318,7 +1318,7 @@ A2T.default <- function(x, action=NULL, byref=FALSE, ...) {
 #'
 #' @export
 #'
-A2T.filter_spct <- function(x, action="add", byref=FALSE, ...) {
+A2T.filter_spct <- function(x, action="add", byref = FALSE, ...) {
   if (byref) {
     name <- substitute(x)
   }
@@ -1369,7 +1369,7 @@ T2A <- function(x, action, byref, ...) UseMethod("T2A")
 #'
 #' @export
 #'
-T2A.default <- function(x, action=NULL, byref=FALSE, ...) {
+T2A.default <- function(x, action=NULL, byref = FALSE, ...) {
   if (any(x < 0)) {
     Tfr.zero <- getOption("photobiology.Tfr.zero", default = 1e-10)
     warning("Replacing zeros by", Tfr.zero)
@@ -1382,7 +1382,7 @@ T2A.default <- function(x, action=NULL, byref=FALSE, ...) {
 #'
 #' @export
 #'
-T2A.filter_spct <- function(x, action="add", byref=FALSE, ...) {
+T2A.filter_spct <- function(x, action="add", byref = FALSE, ...) {
   if (byref) {
     name <- substitute(x)
   }
@@ -1438,7 +1438,7 @@ e2q <- function(x, action, byref, ...) UseMethod("e2q")
 #'
 #' @export
 #'
-e2q.default <- function(x, action="add", byref=FALSE, ...) {
+e2q.default <- function(x, action="add", byref = FALSE, ...) {
   return(NA)
 }
 
@@ -1446,7 +1446,7 @@ e2q.default <- function(x, action="add", byref=FALSE, ...) {
 #'
 #' @export
 #'
-e2q.source_spct <- function(x, action="add", byref=FALSE, ...) {
+e2q.source_spct <- function(x, action="add", byref = FALSE, ...) {
   if (byref) {
     name <- substitute(x)
   }
@@ -1471,7 +1471,7 @@ e2q.source_spct <- function(x, action="add", byref=FALSE, ...) {
 #'
 #' @export
 #'
-e2q.response_spct <- function(x, action="add", byref=FALSE, ...) {
+e2q.response_spct <- function(x, action="add", byref = FALSE, ...) {
   if (byref) {
     name <- substitute(x)
   }
@@ -1528,7 +1528,7 @@ q2e <- function(x, action, byref, ...) UseMethod("q2e")
 #'
 #' @export
 #'
-q2e.default <- function(x, action="add", byref=FALSE, ...) {
+q2e.default <- function(x, action="add", byref = FALSE, ...) {
   return(NA)
 }
 
@@ -1536,7 +1536,7 @@ q2e.default <- function(x, action="add", byref=FALSE, ...) {
 #'
 #' @export
 #'
-q2e.source_spct <- function(x, action="add", byref=FALSE, ...) {
+q2e.source_spct <- function(x, action="add", byref = FALSE, ...) {
   if (byref) {
     name <- substitute(x)
   }
@@ -1561,7 +1561,7 @@ q2e.source_spct <- function(x, action="add", byref=FALSE, ...) {
 #'
 #' @export
 #'
-q2e.response_spct <- function(x, action="add", byref=FALSE, ...) {
+q2e.response_spct <- function(x, action="add", byref = FALSE, ...) {
   if (byref) {
     name <- substitute(x)
   }
